@@ -23,6 +23,10 @@ import os
 import ConfigParser
 import subprocess
 import osso
+import xml.etree.ElementTree as ET
+
+a_name = "Quick Clip"
+a_version = "0.4.0"
 
 history = []
 history_target = []
@@ -43,6 +47,8 @@ class statusbar_applet(hildondesktop.StatusbarItem):
       self.add(self.button)
       self.show_all()
 
+      self.create_files()
+
 # Main menu
 
    def create_menu(self):
@@ -64,6 +70,28 @@ class statusbar_applet(hildondesktop.StatusbarItem):
       self.menu.connect("selection-done", self.menu_done)
       self.menu.show_all()
 
+# Main menu call
+
+   def popup_menu(self,widget,data=None):
+      if (self.button.get_active() == True) :
+         self.create_menu()
+         self.menu.popup(None,None,self.menu_position,0,gtk.get_current_event_time())
+
+# Cleaup?
+
+   def menu_done(self, widget, data=None):
+      self.button.set_active(False)
+      self.menu.destroy()
+
+   def menu_position(self,data=None):
+      (reqw, reqh) = self.menu.size_request()
+      (x,y) = self.button.get_parent_window().get_position()
+      button_allocation = self.button.get_allocation()
+      y = y + button_allocation.y + button_allocation.height
+      x = x + button_allocation.x + button_allocation.width - reqw
+      return (x,y,True)
+# ===================   
+
    def default_menu_positioning_func(self):
 
       menu_group = gtk.MenuItem("Options")
@@ -89,34 +117,12 @@ class statusbar_applet(hildondesktop.StatusbarItem):
 
       self.history_menu()
 
-# Main menu call
-
-   def popup_menu(self,widget,data=None):
-      if (self.button.get_active() == True) :
-         self.create_menu()
-         self.menu.popup(None,None,self.menu_position,0,gtk.get_current_event_time())
-
-# Cleaup?
-
-   def menu_done(self, widget, data=None):
-      self.button.set_active(False)
-      self.menu.destroy()
-
-   def menu_position(self,data=None):
-      (reqw, reqh) = self.menu.size_request()
-      (x,y) = self.button.get_parent_window().get_position()
-      button_allocation = self.button.get_allocation()
-      y = y + button_allocation.y + button_allocation.height
-      x = x + button_allocation.x + button_allocation.width - reqw
-      return (x,y,True)
-# ============================      
-
 # About dialog
 
    def about_dialog(self,widget,data=None):
       about_quick_clip = gtk.AboutDialog()
-      about_quick_clip.set_name("Quick Clip")
-      about_quick_clip.set_version("0.3.0")
+      about_quick_clip.set_name(a_name)
+      about_quick_clip.set_version(a_version)
       about_quick_clip.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/icons/hicolor/40x40/hildon/quick_clip-40x40.png"))
       about_quick_clip.set_comments("""
 The fast and easy way to copy and save information.
@@ -142,7 +148,7 @@ License along with this program.  If not, see
       about_quick_clip.run()
       about_quick_clip.destroy()
 
-# Settings dialog
+# Settings Dialog
 
    def settings(self,widget,data=None):
 
@@ -153,35 +159,35 @@ License along with this program.  If not, see
 
       settings = self.get_settings()
 
-      path_entry = gtk.Entry()
+      self.path_entry = gtk.Entry()
       path_button = gtk.Button("Open")
-      view_entry = gtk.Entry()
-      edit_entry = gtk.Entry()
+      self.view_entry = gtk.Entry()
+      self.edit_entry = gtk.Entry()
 
-      path_entry.set_width_chars(30)
-      view_entry.set_width_chars(30)
-      edit_entry.set_width_chars(30)
+      self.path_entry.set_width_chars(30)
+      self.view_entry.set_width_chars(30)
+      self.edit_entry.set_width_chars(30)
 
-      path_entry.set_text(settings['path'])
-      view_entry.set_text(settings['view_program'])
-      edit_entry.set_text(settings['edit_program'])
+      self.path_entry.set_text(settings['path'])
+      self.view_entry.set_text(settings['view_program'])
+      self.edit_entry.set_text(settings['edit_program'])
 
-      use_date_stamp_checkbutton = gtk.CheckButton("Use Date Stamp")
-      use_separater_checkbutton = gtk.CheckButton("Use Separater")
+      self.use_date_stamp_checkbutton = gtk.CheckButton("Use Date Stamp")
+      self.use_separater_checkbutton = gtk.CheckButton("Use Separater")
 
-      combobox = gtk.combo_box_new_text()
-      combobox.set_size_request(300, -1)
-      combobox.append_text("Top")
-      combobox.append_text("Bottom")
+      self.combobox = gtk.combo_box_new_text()
+      self.combobox.set_size_request(300, -1)
+      self.combobox.append_text("Top")
+      self.combobox.append_text("Bottom")
 
-      ok_button.connect('clicked', self.settings_callback, path_entry, view_entry, edit_entry, use_date_stamp_checkbutton, use_separater_checkbutton, combobox)
+      ok_button.connect('clicked', self.settings_callback)
       reset_button.connect('clicked', self.set_default_settings)
-      path_button.connect('clicked', self.path_button_callback, path_entry)
+      path_button.connect('clicked', self.path_button_callback)
 
-      use_date_stamp_checkbutton.set_active(settings['use_date_stamp'])
-      use_separater_checkbutton.set_active(settings['use_separater'])
+      self.use_date_stamp_checkbutton.set_active(settings['use_date_stamp'])
+      self.use_separater_checkbutton.set_active(settings['use_separater'])
 
-      combobox.set_active(settings['default_menu_positioning'])
+      self.combobox.set_active(settings['default_menu_positioning'])
 
       path_hbox = gtk.HBox()
       path_button_hbox = gtk.HBox()
@@ -191,15 +197,15 @@ License along with this program.  If not, see
       combobox_hbox = gtk.HBox()
 
       path_hbox.pack_start(gtk.Label("Storage Path:"), False, 5, 10)
-      path_hbox.pack_end(path_entry)
+      path_hbox.pack_end(self.path_entry)
       view_hbox.pack_start(gtk.Label("View Program:"), False, 5, 5)
-      view_hbox.pack_end(view_entry)
+      view_hbox.pack_end(self.view_entry)
       edit_hbox.pack_start(gtk.Label("Edit Program:"), False, 5, 9)
-      edit_hbox.add(edit_entry)
-      checkbox_hbox.pack_start(use_date_stamp_checkbutton, False, 5, 70)
-      checkbox_hbox.pack_end(use_separater_checkbutton, False, 5, 70)
+      edit_hbox.add(self.edit_entry)
+      checkbox_hbox.pack_start(self.use_date_stamp_checkbutton, False, 5, 70)
+      checkbox_hbox.pack_end(self.use_separater_checkbutton, False, 5, 70)
       combobox_hbox.pack_start(gtk.Label("Options/History Displayed:"), False, 5, 60)
-      combobox_hbox.pack_end(combobox, False, 5, 70)
+      combobox_hbox.pack_end(self.combobox, False, 5, 70)
 
       path_button_hbox.pack_start(path_hbox)
       path_button_hbox.pack_end(path_button)
@@ -216,7 +222,7 @@ License along with this program.  If not, see
       settings_dialog.run()     
       settings_dialog.destroy()
 
-   def path_button_callback(self, widget, path_entry):
+   def path_button_callback(self, widget):
       dialog = gtk.FileChooserDialog("Choose Path", None, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER, (gtk.STOCK_OPEN, gtk.RESPONSE_OK, gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
       response = dialog.run()
 
@@ -231,18 +237,17 @@ License along with this program.  If not, see
          return None
 
       dialog.destroy()
-      path_entry.set_text(path)
+      self.settings.path_entry.set_text(path)
 
 # Settings Dialog entry callback
 
-   def settings_callback(self, widget, path_entry, view_entry, edit_entry, use_date_stamp_checkbutton, use_separater_checkbutton, combobox):
-      path = path_entry.get_text()
-      view_program = view_entry.get_text()
-      edit_program = edit_entry.get_text()
-      use_date_stamp = use_date_stamp_checkbutton.get_active()
-      use_separater = use_separater_checkbutton.get_active()
-      default_menu_positioning = combobox.get_active()
-      print default_menu_positioning
+   def settings_callback(self, widget):
+      path = self.path_entry.get_text()
+      view_program = self.view_entry.get_text()
+      edit_program = self.edit_entry.get_text()
+      use_date_stamp = self.use_date_stamp_checkbutton.get_active()
+      use_separater = self.use_separater_checkbutton.get_active()
+      default_menu_positioning = self.combobox.get_active()
 
       self.set_settings(path, view_program, edit_program, use_date_stamp, use_separater, default_menu_positioning)
 
@@ -277,17 +282,17 @@ License along with this program.  If not, see
       main_vbox.pack_start(up_button, True, 5, 5)
       main_vbox.pack_start(down_button, True, 5, 5)
 
-      liststore = gtk.ListStore(str)
+      self.liststore = gtk.ListStore(str)
 
       files_list = self.get_files()
 
       for item in files_list:
-         liststore.append([item])
+         self.liststore.append([item])
 
-      treeview = gtk.TreeView(liststore)
-      treeview.set_reorderable(True)
+      self.treeview = gtk.TreeView(self.liststore)
+      self.treeview.set_reorderable(True)
       tvcolumn = gtk.TreeViewColumn('Column 0')
-      treeview.append_column(tvcolumn)
+      self.treeview.append_column(tvcolumn)
       cell = gtk.CellRendererText()
       tvcolumn.pack_start(cell, True)
       tvcolumn.add_attribute(cell, 'text', 0)
@@ -295,7 +300,7 @@ License along with this program.  If not, see
       scrolled_window = gtk.ScrolledWindow()
       scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
       scrolled_window.set_size_request(400, -1)
-      scrolled_window.add(treeview)
+      scrolled_window.add(self.treeview)
 
       list_vbox.pack_start(scrolled_window, True, 5, 5)
 
@@ -304,12 +309,12 @@ License along with this program.  If not, see
 
       files_dialog.vbox.pack_start(hbox)
 
-      ok_button.connect('clicked', self.ok_button_callback, treeview)
-      new_file_button.connect('clicked', self.new_file_button_dialog, liststore)
-      delete_file_button.connect('clicked', self.delete_file_button_callback, liststore, treeview)
-      rename_button.connect('clicked', self.rename_button_callback, liststore, treeview)
-      up_button.connect('clicked', self.up_button_callback, liststore, treeview)
-      down_button.connect('clicked', self.down_button_callback, liststore, treeview)
+      ok_button.connect('clicked', self.ok_button_callback)
+      new_file_button.connect('clicked', self.new_file_button_dialog)
+      delete_file_button.connect('clicked', self.delete_file_button_callback)
+      rename_button.connect('clicked', self.rename_button_callback)
+      up_button.connect('clicked', self.up_button_callback)
+      down_button.connect('clicked', self.down_button_callback)
 
       hildonhelp.help_dialog_help_enable(files_dialog, "osso_quickclip_manage", osso_context)
 
@@ -317,15 +322,16 @@ License along with this program.  If not, see
       files_dialog.run()     
       files_dialog.destroy()
 
-# OK button callback
+   def ok_button_callback(self, widget):
+      files_list = self.treeview.get_model()
 
-   def ok_button_callback(self, widget, treeview):
-      files_list = treeview.get_model()               
-      self.set_files(files_list)
+      files = []
 
-# New file dialog
+      for item in files_list:
+         files.append(item[0])             
+      self.set_files(files)
 
-   def new_file_button_dialog(self, widget, liststore):
+   def new_file_button_dialog(self, widget):
 
       dialog = gtk.Dialog("Enter New Name",None,gtk.DIALOG_MODAL)
       dialog.set_size_request(300, -1)
@@ -334,7 +340,7 @@ License along with this program.  If not, see
 
       entry = gtk.Entry(20)
 
-      ok_button.connect('clicked', self.new_file_entry_callback, entry, liststore)
+      ok_button.connect('clicked', self.new_file_entry_callback, entry)
 
       dialog.vbox.pack_start(entry, True, 10, 10)
 
@@ -342,75 +348,63 @@ License along with this program.  If not, see
       dialog.run()     
       dialog.destroy()
 
-# New file callback
-
-   def new_file_entry_callback(self, widget, entry, liststore):
+   def new_file_entry_callback(self, widget, entry):
       text = entry.get_text()
       if text == "":
          return
-      liststore.append([text])
+      self.liststore.append([text])
 
-# Delete file callback
-
-   def delete_file_button_callback(self, widget, liststore, treeview):
-      selection = treeview.get_selection()
+   def delete_file_button_callback(self, widget):
+      selection = self.treeview.get_selection()
       model, treeiter = selection.get_selected()
       if treeiter is not None:
          model.remove(treeiter)
 
-# Rename file dialog
-
-   def rename_button_callback(self, widget, liststore, treeview):
+   def rename_button_callback(self, widget):
 
       dialog = gtk.Dialog("Enter New Name",None,gtk.DIALOG_MODAL)
       dialog.set_size_request(300, -1)
       ok_button = dialog.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
       cancel_button = dialog.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
 
-      entry = gtk.Entry(20)
+      self.entry = gtk.Entry(20)
 
-      ok_button.connect('clicked', self.rename_file_entry_callback, entry, liststore, treeview)
+      ok_button.connect('clicked', self.rename_file_entry_callback)
 
-      dialog.vbox.pack_start(entry, True, 10, 10)
+      dialog.vbox.pack_start(self.entry, True, 10, 10)
 
       dialog.show_all()
       dialog.run()     
       dialog.destroy()
 
-# Rename file callback
-
-   def rename_file_entry_callback(self, widget, entry, liststore, treeview):
-      text = entry.get_text()
+   def rename_file_entry_callback(self, widget):
+      text = self.entry.get_text()
       if text == "":
          return
 
-      selection = treeview.get_selection()
+      selection = self.treeview.get_selection()
       model, treeiter = selection.get_selected()
-      liststore.set(treeiter, 0 , text)
+      self.liststore.set(treeiter, 0 , text)
 
-# Up  button callback
-
-   def up_button_callback(self, widget, liststore, treeview):
-      selection = treeview.get_selection()
+   def up_button_callback(self, widget):
+      selection = self.treeview.get_selection()
       model, treeiter = selection.get_selected()
-      path = liststore.get_path(treeiter)
+      path = self.liststore.get_path(treeiter)
       a_row = path[0]
       b_row = a_row - 1
       a = treeiter
-      b = liststore.get_iter(b_row)
-      liststore.swap(a, b)
+      b = self.liststore.get_iter(b_row)
+      self.liststore.swap(a, b)
 
-# Down button callback
-
-   def down_button_callback(self, widget, liststore, treeview):
-      selection = treeview.get_selection()
+   def down_button_callback(self, widget):
+      selection = self.treeview.get_selection()
       model, treeiter = selection.get_selected()
-      path = liststore.get_path(treeiter)
+      path = self.liststore.get_path(treeiter)
       a_row = path[0]
       b_row = a_row + 1
       a = treeiter
-      b = liststore.get_iter(b_row)
-      liststore.swap(a, b)
+      b = self.liststore.get_iter(b_row)
+      self.liststore.swap(a, b)
 
 # Donations
 
@@ -466,14 +460,22 @@ Brent Chiodo""")
          menu_entry = gtk.MenuItem("Entry >> File")
          menu_view = gtk.MenuItem("View")
          menu_edit = gtk.MenuItem("Edit")
+         menu_clear = gtk.MenuItem("Clear")
+         menu_delete = gtk.MenuItem("Delete")
          self.submenu.append(menu_selection)
          self.submenu.append(menu_entry)
+         self.submenu.append(gtk.SeparatorMenuItem())
          self.submenu.append(menu_view)
          self.submenu.append(menu_edit)
+         self.submenu.append(gtk.SeparatorMenuItem())
+         self.submenu.append(menu_clear)
+         self.submenu.append(menu_delete)
          menu_selection.connect('activate', self.clip_selection, item)
          menu_entry.connect('activate', self.entry_dialog, item)
          menu_view.connect('activate', self.view_file, item)
          menu_edit.connect('activate', self.edit_file, item)
+         menu_clear.connect('activate', self.clear_file, item)
+         menu_delete.connect('activate', self.delete_file, item)
          menu_group.set_submenu(self.submenu)
 
 # The Entry >> File dialog
@@ -584,8 +586,10 @@ Brent Chiodo""")
 
       settings = self.get_settings()
       if settings['view_program'] == "$builtin":
-         command = '/usr/bin/quickclip_viewer.py "%s"' % (settings['path'] + name)
-         command = command + '.txt'
+         command = '/usr/bin/quickclip_viewer.py "%s"' % (name)
+         if not os.path.exists(settings['path'] + name + '.txt'):
+            hildon.hildon_banner_show_information(self.submenu, "qgn_note_gene_syserror", "Error: File does not exist (have you clipped anything into it?)")
+            return
          subprocess.Popen(command, shell=True)
       else:
          command = settings['view_program'] % (settings['path'] + name)
@@ -601,6 +605,66 @@ Brent Chiodo""")
       command = command + '.txt'
       subprocess.Popen(command, shell=True)
 
+# Clear function
+
+   def clear_file(self, widget, name):
+      dialog = gtk.MessageDialog(None,gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION)
+      yes_button = dialog.add_button(gtk.STOCK_YES, gtk.RESPONSE_YES)
+      no_button = dialog.add_button(gtk.STOCK_NO, gtk.RESPONSE_NO)
+
+      settings = self.get_settings()
+
+      text = "Are you sure you want to permanently erase the contents of <b>" + name + "</b>?"
+      dialog.set_markup(text)
+
+      response = dialog.run()
+
+      if response == gtk.RESPONSE_YES:
+         try:
+            file = settings['path'] + name + '.txt'
+            os.remove(file)
+            f = open(file, 'w')
+            f.close()
+            hildon.hildon_banner_show_information(self.submenu, None, name + " Deleted.")
+         except OSError, e:
+            hildon.hildon_banner_show_information(self.submenu, "qgn_note_gene_syserror", str(e))
+      else:
+         dialog.destroy()
+         return
+
+      dialog.destroy()
+
+# Delete function
+
+   def delete_file(self, widget, name):
+      dialog = gtk.MessageDialog(None,gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION)
+      yes_button = dialog.add_button(gtk.STOCK_YES, gtk.RESPONSE_YES)
+      no_button = dialog.add_button(gtk.STOCK_NO, gtk.RESPONSE_NO)
+
+      settings = self.get_settings()
+
+      text = "Are you sure you want to permanently delete <b>" + name + "</b>?"
+      dialog.set_markup(text)
+
+      response = dialog.run()
+
+      if response == gtk.RESPONSE_YES:
+         try:
+            file = settings['path'] + name + '.txt'
+            os.remove(file)
+            files = self.get_files()
+            files.remove(name)
+            self.set_files(files)
+            hildon.hildon_banner_show_information(self.submenu, None, name + " Deleted.")
+
+         except Exception, e:
+            hildon.hildon_banner_show_information(self.submenu, "qgn_note_gene_syserror", str(e))
+      else:
+         dialog.destroy()
+         return
+
+      dialog.destroy()
+
 # History menu
 
    def history_menu(self):
@@ -646,44 +710,60 @@ Brent Chiodo""")
       if len(history) > 10:
          del history[-1]
 
-# Get parent files
+# Parent Files processing
 
-   def get_files(self):
+   def create_files(self):
+      files = self.get_files()
+      settings = self.get_settings()
+      for item in files:
+         if not os.path.exists(settings['path'] + item + '.txt'):
+            command = 'touch "%s%s%s"' % (settings['path'], item, '.txt')
+            subprocess.Popen(command, shell=True)
 
-      parent_file = open('/home/user/.quickclip/parent_files', 'r')
-      parent_file.seek(0)
-      file_contents = parent_file.readlines()
-
-      files_list = []
-
-      for line in file_contents:
-         name = line
-         name = name.strip('\n')
-         files_list.append(name)
-
-      return files_list
-
-# Set parent files
+   def indent(self, elem, level=0):
+      i = "\n" + level*"  "
+      if len(elem):
+         if not elem.text or not elem.text.strip():
+            elem.text = i + "  "
+         if not elem.tail or not elem.tail.strip():
+            elem.tail = i
+         for elem in elem:
+            self.indent(elem, level+1)
+         if not elem.tail or not elem.tail.strip():
+            elem.tail = i
+      else:
+         if level and (not elem.tail or not elem.tail.strip()):
+            elem.tail = i
 
    def set_files(self, files):
 
-      parent_file = open('/home/user/.quickclip/parent_files', 'w')
-
-      count = 0
+      root = ET.Element("config")
 
       for item in files:
-         parent_file.write(item[0])
+         file = ET.SubElement(root, "file")
+         file.text = item
 
-         if count < len(files):
-            parent_file.write('\n')
+      self.indent(root)
+      tree = ET.ElementTree(root)
+      tree.write("/home/user/.quickclip/parent_files.xml")
 
-      parent_file.close()
+      self.create_files()
+
+   def get_files(self):
+      tree = ET.parse("/home/user/.quickclip/parent_files.xml")
+      elements = tree.getroot()
+      files_list = []
+
+      for subelement in elements:
+         files_list.append(subelement.text)
+
+      return files_list
 
 # Get User's settings
 
    def get_settings(self):
 
-      user_config_file = open('/home/user/.quickclip/user.conf', 'r')
+      user_config_file = open('/home/user/.quickclip/quickclip.conf', 'r')
       user_config_access = ConfigParser.RawConfigParser()
       user_config_access.readfp(user_config_file)
 
@@ -717,7 +797,7 @@ Brent Chiodo""")
 
    def set_settings(self, path, view_program, edit_program, use_date_stamp, use_separater, default_menu_positioning):
 
-      user_config_file = open('/home/user/.quickclip/user.conf', 'w')
+      user_config_file = open('/home/user/.quickclip/quickclip.conf', 'w')
       user_config_access = ConfigParser.RawConfigParser()
 
       user_config_access.set('DEFAULT', 'path', path)
@@ -734,10 +814,10 @@ Brent Chiodo""")
 
    def set_default_settings(self, widget, data=None):
 
-      user_config_file = open('/home/user/.quickclip/user.conf', 'w')
+      user_config_file = open('/home/user/.quickclip/quickclip.conf', 'w')
       user_config_access = ConfigParser.RawConfigParser()
 
-      user_config_access.set('DEFAULT', 'path', '/home/user/.quickclip/data/')
+      user_config_access.set('DEFAULT', 'path', '/home/user/MyDocs/Quick_Clip/')
       user_config_access.set('DEFAULT', 'view_program', '$builtin')
       user_config_access.set('DEFAULT', 'edit_program', '/usr/bin/dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:"%s"')
       user_config_access.set('DEFAULT', 'use_date_stamp', True)
@@ -754,12 +834,12 @@ Brent Chiodo""")
 if not os.path.exists('/home/user/.quickclip/'):
    subprocess.Popen('mkdir /home/user/.quickclip', shell=True)
 
-if not os.path.exists('/home/user/.quickclip/data/'):
-   subprocess.Popen('mkdir /home/user/.quickclip/data', shell=True)
+if not os.path.exists('/home/user/MyDocs/Quick_Clip/'):
+   subprocess.Popen('mkdir /home/user/MyDocs/Quick_Clip/', shell=True)
 
-if not os.path.exists('/home/user/.quickclip/user.conf'):
+if not os.path.exists('/home/user/.quickclip/quickclip.conf'):
 
-   user_config_file = open('/home/user/.quickclip/user.conf', 'w')
+   user_config_file = open('/home/user/.quickclip/quickclip.conf', 'w')
    user_config_access = ConfigParser.RawConfigParser()
 
    user_config_access.set('DEFAULT', 'path', '/home/user/.quickclip/data/')
@@ -772,11 +852,14 @@ if not os.path.exists('/home/user/.quickclip/user.conf'):
    user_config_access.write(user_config_file)
    user_config_file.close()
 
-if not os.path.exists('/home/user/.quickclip/parent_files'):
+if not os.path.exists('/home/user/.quickclip/parent_files.xml'):
 
-   parent_files = open('/home/user/.quickclip/parent_files', 'w')
-   parent_files.write('Example File 1\nExample File 2\nEtc...')
-   parent_files.close()
+   parent_files = open('/home/user/.quickclip/parent_files.xml', 'w')
+   parent_files.write("""<config>
+  <file>Example File 1</file>
+  <file>Example File 2</file>
+  <file>Etc...</file>
+</config>""")
 
 # ============================
 # Main program
@@ -784,4 +867,5 @@ if not os.path.exists('/home/user/.quickclip/parent_files'):
 def hd_plugin_get_objects():
    plugin = statusbar_applet()
    return [plugin]
+
 # ============================
\ No newline at end of file
